<?php

namespace App\Http\Controllers\Admin;

use App\Models\AdminUserModel;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class AdminUserController extends Controller
{
    protected $redirect_index = '/admin/AdminUser/index';

    protected $view_path = 'admin.admin-users.';

    protected $pre_uri = '/admin/AdminUser/';

    protected $model_name = '账号';

    protected $model;

    public function __construct()
    {
        parent::__construct();
        $this->model = new AdminUserModel();
    }

    public function index(Request $request)
    {
        $list = $this->model->where('id', '>', 0)->orderBy('created_at', 'desc');

        if(!empty($request->input('keyword')) && !empty(trim($request->input('keyword')))) {
            $keyword = '%' . trim($request->input('keyword')) . '%';
            $list = $list->where('name', 'like', $keyword);
        }

        $list = $list->paginate()->withPath($this->getPaginateUrl());

        list($pre_uri, $model_name) = array($this->pre_uri, $this->model_name);
        return view($this->view_path . 'index', compact('list', 'pre_uri', 'model_name'));
    }

    public function create(Request $request)
    {
        list($pre_uri, $model_name, $model) = array($this->pre_uri, $this->model_name, $this->model);
        return view($this->view_path . 'create', compact('pre_uri', 'model_name', 'model'));
    }

    public function store(Request $request)
    {
        if(!$request->isMethod('POST')) {
            return $this->showWarning('访问错误');
        }

        if(empty($request->input('data')) || !is_array($request->input('data'))) {
            return $this->showWarning('数据错误');
        }

        $validator = Validator::make($request->all(), [
            'name' => 'required|unique:admin_users',
            'password' => 'required|min:6'
        ], [
            'name.required' => '用户名必填',
            'name.unique' => '用户名已存在',
            'password.unique' => '密码必填',
            'password.min' => '密码不能小于6位',
        ]);
        if($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }

        $data = $request->input('data');
        $data['password'] = bcrypt($data['password']);

        $res = $this->model->create($data);

        if(!$res) {
            return $this->showWarning('数据库保存失败！');
        }
        return $this->showMessage('操作成功', $this->redirect_index);
    }

    public function edit(Request $request)
    {
        if(empty($request->input('id')) || empty($item = $this->model->find($request->input('id')))) {
            return $this->showWarning('数据错误！');
        }
        list($pre_uri, $model_name, $model) = array($this->pre_uri, $this->model_name, $this->model);

        return view($this->view_path . 'edit', compact('item','pre_uri', 'model_name', 'model'));
    }

    public function update(Request $request)
    {
        if(!$request->isMethod('POST')) {
            return $this->showWarning('访问错误');
        }

        if(empty($request->input('id')) || empty($request->input('data')) || !is_array($request->input('data'))) {
            return $this->showWarning('数据错误');
        }

        $validator = Validator::make($request->input('data'), [
            'name' => 'required'
        ], [
            'name.required' => '用户名必填'
        ]);

        if($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }

        $data = $request->input('data');

        $tmp = $this->model->where([
            ['name', '=', $data['name']],
            ['id', '<>', $request->input('id')],
        ])->first();
        if(!empty($tmp)) {
            $validator->errors()->add('name', '用户名已存在');
            return back()->withErrors($validator)->withInput();
        }

        if($request->has('is_update_password') && $request->input('is_update_password') == 1) {
            $data['password'] = bcrypt($request->input('password', 123456));
        }

        $res = $this->model->where('id', $request->input('id'))->update($data);

        if(!$res) {
            return $this->showWarning('数据库保存失败！');
        }
        return $this->showMessage('操作成功', $this->redirect_index);
    }

    public function delete(Request $request)
    {
        if(!$request->isMethod('POST')) {
            return $this->showWarning('访问错误');
        }
        if(empty($request->input('id')) || empty($item = $this->model->find($request->input('id')))) {
            return $this->showWarning('访问错误');
        }

        $res = $item->delete();
        if(!$res) {
            return $this->showWarning('数据库删除失败');
        }
        return $this->showMessage('操作成功');
    }
}
